#include "TextInput.h"

#define Inherited CTextInputData

CTextInput::CTextInput(QWidget* parent,const char* name)
    :Inherited( parent, name )
{
    setCaption( "KMySQL - New Database" );
    InputField->setFocus();
    OkButton->setEnabled(FALSE);
}


CTextInput::~CTextInput()
{
}

void CTextInput::accept_field()
{
    QString s = InputField->text();
    if (s.isEmpty())
        return;
    QDialog::accept();
}

void CTextInput::inputChanged(const QString&text)
{
    if (!text.isEmpty())
        OkButton->setEnabled(TRUE);
    else
        OkButton->setEnabled(FALSE);
}

void CTextInput::set_label_text(const char* text)
{
    if (!text)
        return;
    InputLabel->setText(text);
}
